# Code of Conduct (CoC)

The GETTSIM community is made up of members from around the globe with a
diverse set of skills, personalities, and experiences. It is through
these differences that our community experiences great successes and
continued growth. When you're working with members of the community,
this CoC will help steer your interactions and keep GETTSIM a positive,
successful, and growing community.

## Our Community

Members of the GETTSIM community are open, considerate, and respectful.
Behaviours that reinforce these values contribute to a positive
environment, and include:

-   *Being open*. Members of the community are open to collaboration,
    whether it's on feature requests, patches, problems, or otherwise.
-   *Focusing on what is best for the community*. We're respectful of
    the processes set forth in the community, and we work within them.
-   *Acknowledging time and effort*. We're respectful of the volunteer
    efforts that permeate the GETTSIM community. We're thoughtful when
    addressing the efforts of others, keeping in mind that often times
    the labor was completed simply for the good of the community.
-   *Being respectful of differing viewpoints and experiences*. We're
    receptive to constructive comments and criticism, as the experiences
    and skill sets of other members contribute to the whole of our
    efforts.
-   *Showing empathy towards other community members*. We're attentive
    in our communications, whether in person or online, and we're
    tactful when approaching differing views.
-   *Being considerate*. Members of the community are considerate of
    their peers -- other GETTSIM users.
-   *Being respectful*. We're respectful of others, their positions,
    their skills, their commitments, and their efforts.
-   *Gracefully accepting constructive criticism*. When we disagree, we
    are courteous in raising our issues.
-   *Using welcoming and inclusive language*. We're accepting of all who
    wish to take part in our activities, fostering an environment where
    anyone can participate and everyone can make a difference.

## Our Standards

Every member of our community has the right to have their identity
respected. The GETTSIM community is dedicated to providing a positive
experience for everyone, regardless of age, gender identity and
expression, sexual orientation, disability, physical appearance, body
size, ethnicity, nationality, race, or religion (or lack thereof),
education, or socio-economic status.

### Inappropriate Behavior

Examples of unacceptable behavior by participants include:

-   Harassment of any participants in any form.
-   Deliberate intimidation, stalking, or following.
-   Logging or taking screenshots of online activity for harassment
    purposes.
-   Publishing others' private information, such as a physical or
    electronic address, without explicit permission.
-   Violent threats or language directed against another person.
-   Incitement of violence or harassment towards any individual,
    including encouraging a person to commit suicide or to engage in
    self-harm.
-   Creating additional online accounts in order to harass another
    person or circumvent a ban.
-   Sexual language and imagery in online communities or in any
    conference venue, including talks.
-   Insults, put downs, or jokes that are based upon stereotypes, that
    are exclusionary, or that hold others up for ridicule.
-   Excessive swearing.
-   Unwelcome sexual attention or advances.
-   Unwelcome physical contact, including simulated physical contact
    (eg, textual descriptions like "hug" or "backrub") without consent
    or after a request to stop.
-   Pattern of inappropriate social contact, such as requesting/assuming
    inappropriate levels of intimacy with others.
-   Sustained disruption of online community discussions, in-person
    presentations, or other in-person events.
-   Continued one-on-one communication after requests to cease.
-   Other conduct that is inappropriate for a professional audience
    including people of many different backgrounds.

Community members asked to stop any inappropriate behavior are expected
to comply immediately.

## Consequences

If a participant engages in behavior that violates this CoC, the GETTSIM
community CoC team may take any action they deem appropriate, including
editing/removing inappropriate content, warning the offender or
expulsion from the community. The CoC team is made up of GETTSIM
contributors and users and will react promptly to reports. The current
team includes

-   [Boryana Ilieva](https://github.com/boryana-ilieva)
-   [Holger Stichnoth](https://github.com/stichnoth)
-   [Maximilian Blesch](https://github.com/MaxBlesch)

All complaints will be reviewed and investigated and will result in a
response that is deemed necessary and appropriate to the circumstances.
The GETTSIM CoC team is obligated to maintain confidentiality with
regard to the reporter of an incident. In cases of conflicts of
interest, CoC team members have to remove themselves from decision
process without the need to further specify their conflict.

## A Last Note

Thank you for helping make this a welcoming, friendly community for
everyone.

## Acknowledgment

This CoC is derived if not copied from the [CoC of the Python Software
Foundation (PSF)](https://www.python.org/psf/conduct/) and includes
parts from the [CoC of
pandas](https://github.com/pandas-dev/pandas-governance/blob/master/code-of-conduct.md).
